@@ -2,6 +2,7 @@ package m
 
 import (
 	"fmt"
+	"math"
 	"regexp"
 	"time"
 
@@ -59,7 +60,9 @@ type Pager struct {
 	searchString   string
 	searchPattern  *regexp.Regexp
 	gotoLineString string
-	Following      bool
+
+	// We used to have a "Following" field here. If you want to follow, set
+	// TargetLineNumberOneBased to math.MaxInt instead, see below.
 
 	isShowingHelp bool
 	preHelpState  *_PreHelpState
@@ -83,16 +86,20 @@ type Pager struct {
 
 	SideScrollAmount int // Should be positive
 
+	// If non-zero, scroll to this line number as soon as possible. Set to
+	// math.MaxInt to follow the end of the input (tail).
+	TargetLineNumberOneBased int
+
 	// If true, pager will clear the screen on return. If false, pager will
 	// clear the last line, and show the cursor.
 	DeInit bool
 }
 
 type _PreHelpState struct {
-	reader              *Reader
-	scrollPosition      scrollPosition
-	leftColumnZeroBased int
-	following           bool
+	reader                   *Reader
+	scrollPosition           scrollPosition
+	leftColumnZeroBased      int
+	targetLineNumberOneBased int
 }
 
 const _EofMarkerFormat = "\x1b[7m" // Reverse video
@@ -117,7 +124,7 @@ Moving around
 * PageUp / 'b' and PageDown / 'f'
 * SPACE moves down a page
 * Home and End for start / end of the document
-* < to go to the start of the document
+* < / 'gg' to go to the start of the document
 * > / 'G' to go to the end of the document
 * 'h', 'l' for left and right (as in vim)
 * Half page 'u'p / 'd'own, or CTRL-u / CTRL-d
@@ -210,7 +217,7 @@ func (p *Pager) Quit() {
 	p.reader = p.preHelpState.reader
 	p.scrollPosition = p.preHelpState.scrollPosition
 	p.leftColumnZeroBased = p.preHelpState.leftColumnZeroBased
-	p.Following = p.preHelpState.following
+	p.TargetLineNumberOneBased = p.preHelpState.targetLineNumberOneBased
 	p.preHelpState = nil
 }
 
@@ -235,11 +242,15 @@ func (p *Pager) moveRight(delta int) {
 }
 
 func (p *Pager) handleScrolledUp() {
-	p.Following = false
+	p.TargetLineNumberOneBased = 0
 }
 
 func (p *Pager) handleScrolledDown() {
-	p.Following = p.isScrolledToEnd()
+	if p.isScrolledToEnd() {
+		p.TargetLineNumberOneBased = math.MaxInt
+	} else {
+		p.TargetLineNumberOneBased = 0
+	}
 }
 
 func (p *Pager) onKey(keyCode twin.KeyCode) {
@@ -326,15 +337,15 @@ func (p *Pager) onRune(char rune) {
 	case '?':
 		if !p.isShowingHelp {
 			p.preHelpState = &_PreHelpState{
-				reader:              p.reader,
-				scrollPosition:      p.scrollPosition,
-				leftColumnZeroBased: p.leftColumnZeroBased,
-				following:           p.Following,
+				reader:                   p.reader,
+				scrollPosition:           p.scrollPosition,
+				leftColumnZeroBased:      p.leftColumnZeroBased,
+				targetLineNumberOneBased: p.TargetLineNumberOneBased,
 			}
 			p.reader = _HelpReader
 			p.scrollPosition = newScrollPosition("Pager scroll position")
 			p.leftColumnZeroBased = 0
-			p.Following = false
+			p.TargetLineNumberOneBased = 0
 			p.isShowingHelp = true
 		}
 
@@ -539,8 +550,15 @@ func (p *Pager) StartPaging(screen twin.Screen) {
 			return
 
 		case eventMoreLinesAvailable:
-			if p.mode.isViewing() && p.Following {
-				p.scrollToEnd()
+			if p.mode.isViewing() && p.TargetLineNumberOneBased > 0 {
+				// The user wants to scroll down to a specific line number
+				if p.reader.GetLineCount() >= p.TargetLineNumberOneBased {
+					p.scrollPosition = NewScrollPositionFromLineNumberOneBased(p.TargetLineNumberOneBased, "goToTargetLineNumber")
+					p.TargetLineNumberOneBased = 0
+				} else {
+					// Not there yet, keep scrolling
+					p.scrollToEnd()
+				}
 			}
 
 		case eventMaybeDone:
